<?php


namespace Drupal\migrate_process_xml\Plugin\migrate\process;

use Drupal\migrate\MigrateException;
use Drupal\migrate\ProcessPluginBase;
use Drupal\migrate\MigrateExecutableInterface;
use Drupal\migrate\Row;

/**
 * Dumps the input value to stdout. Passes the rest through.
 *
 * @MigrateProcessPlugin(
 *   id = "xvalue"
 * )
 *
 */
class Xvalue extends ProcessPluginBase {

  /**
   * {@inheritdoc}
   */
  public function transform($value, MigrateExecutableInterface $migrate_executable, Row $row, $destination_property) {

    // Skip everything if the value is empty.
    if (empty($value)) {
      return $value;
    }

    // Parse the xml in the value.
    $xml = new \SimpleXMLElement($value, \LIBXML_NOWARNING);

    // This plugin needs an xpath parameter to function.
    if (empty($this->configuration['xpath'])) {
      throw new MigrateException('Missing required parameter: xpath');
    }

    // Get the xpath from config.
    $xpath = $this->configuration['xpath'];

    // Run the xpath.
    $results = $xml->xpath($xpath);

    // Reserialize the output as a string.
    $out = [];
    foreach ($results as $result) {
      $out[] = $result->__toString();
    }

    // If there's only one result, return it.
    if (count($out) == 1) {
      return reset($out);
    }

    return $out;
  }
}
